@@ -94,31 +94,31 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='parser',
             name='parser_method',
-            field=models.ForeignKey(related_name='parsers', to='regex_match.ParserMethod'),
+            field=models.ForeignKey(related_name='parsers', to='regex_match.ParserMethod', on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='parser',
             name='polymorphic_ctype',
-            field=models.ForeignKey(related_name='polymorphic_regex_match.parser_set+', editable=False, to='contenttypes.ContentType', null=True),
+            field=models.ForeignKey(related_name='polymorphic_regex_match.parser_set+', editable=False, to='contenttypes.ContentType', null=True, on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='modelrule',
             name='polymorphic_ctype',
-            field=models.ForeignKey(related_name='polymorphic_regex_match.modelrule_set+', editable=False, to='contenttypes.ContentType', null=True),
+            field=models.ForeignKey(related_name='polymorphic_regex_match.modelrule_set+', editable=False, to='contenttypes.ContentType', null=True, on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='matchingrule',
             name='model_rule',
-            field=models.ForeignKey(related_name='matching_rules', to='regex_match.ModelRule'),
+            field=models.ForeignKey(related_name='matching_rules', to='regex_match.ModelRule', on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='regexrule',
             name='matching_rule',
-            field=models.ForeignKey(related_name='regex_rules', to='regex_match.MatchingRule'),
+            field=models.ForeignKey(related_name='regex_rules', to='regex_match.MatchingRule', on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='exceptionparser',
             name='model_exception',
-            field=models.ForeignKey(related_name='parsers', to='regex_match.ModelException'),
+            field=models.ForeignKey(related_name='parsers', to='regex_match.ModelException', on_delete=models.CASCADE),
         ),
     ]
