@@ -3,7 +3,9 @@ from polymorphic.models import PolymorphicModel
 
 
 class Parser(PolymorphicModel):
-    parser_method = models.ForeignKey('ParserMethod', related_name='parsers')
+    parser_method = models.ForeignKey(
+        "ParserMethod", on_delete=models.CASCADE, related_name="parsers"
+    )
     parser_method_params = models.CharField(max_length=100, blank=True, null=True)
     created_at = models.DateTimeField(auto_now_add=True, editable=False)
     updated_at = models.DateTimeField(auto_now=True, editable=False)
